@@ -1,4 +1,6 @@
-package RPC::ExtDirect::Test::Data::Router;
+# This does not need to be indexed by PAUSE
+package
+    RPC::ExtDirect::Test::Data::Router;
 
 use strict;
 use warnings;
